# EIDA Consistency Report: `BGS`

- Seed: `173308`
- Time: `2025-09-08T17:16:21.446322+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `11`
- Consistent: `6`
- Inconsistent: `5`
- Score: **54.55 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `5`

## Dataselect Response Types
- **NoTrace**: `5`
- **SingleTrace**: `6`

---

## Detailed Results
### `GB.ESK.00.HHZ`
- Window: `2007-12-05T22:28:44 → 2007-12-05T22:38:44`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `GB.CWF.00.HHZ`
- Window: `2027-01-18T22:40:57 → 2027-01-18T22:50:57`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `GB.LBWR.00.HHZ`
- Window: `2021-12-27T22:30:13 → 2021-12-27T22:40:13`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `GB.EAB.00.HHE`
- Window: `2027-01-12T16:27:54 → 2027-01-12T16:37:54`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `BN.LLW.00.BHZ`
- Window: `2029-07-04T06:03:28 → 2029-07-04T06:13:28`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `GB.CCA1.00.ENZ`
- Window: `2028-01-13T13:49:52 → 2028-01-13T13:59:52`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `GB.CLGH.00.HHE`
- Window: `2024-03-30T17:39:43 → 2024-03-30T17:49:43`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `GB.LMK.00.HHN`
- Window: `2022-09-13T08:14:05 → 2022-09-13T08:24:05`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `GB.DRUM.00.HHZ`
- Window: `2025-08-16T23:49:10 → 2025-08-16T23:59:10`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `GB.EAB.00.HHN`
- Window: `2028-04-01T13:35:44 → 2028-04-01T13:45:44`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `GB.RSBS.00.HHZ`
- Window: `2022-04-12T04:17:09 → 2022-04-12T04:27:09`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`
